@@ -6,9 +6,10 @@
 """Basic structures of asynchronous jobs."""
 
 from time import sleep
-from typing import Any, Callable, Dict, Optional, Tuple, Type, TypeVar
+from typing import Any, Callable, Dict, Optional, Tuple, Type, TypeVar, Union
 
 from tensorbay.client.requests import Client
+from tensorbay.client.search import FusionSearchResult, SearchResult
 from tensorbay.client.struct import Draft
 from tensorbay.utility import AttrsMixin, ReprMixin, ReprType, attr, camel, common_loads
 
@@ -25,6 +26,7 @@ class Job(AttrsMixin, ReprMixin):  # pylint: disable=too-many-instance-attribute
         job_updater: The function to update the information of the Job instance.
         title: Title of the Job.
         job_id: ID of the Job.
+        job_type: Type of the Job.
         arguments: Arguments of the Job.
         created_at: The time when the Job is created.
         started_at: The time when the Job is started.
@@ -53,6 +55,7 @@ class Job(AttrsMixin, ReprMixin):  # pylint: disable=too-many-instance-attribute
 
     title: str = attr()
     job_id: str = attr(key=camel)
+    _job_type: str = attr(key=camel)
     arguments: Dict[str, Any] = attr()
     created_at: int = attr(key=camel)
     started_at: Optional[int] = attr(key=camel, default=None)
@@ -69,6 +72,7 @@ class Job(AttrsMixin, ReprMixin):  # pylint: disable=too-many-instance-attribute
         job_updater: Callable[[str], Dict[str, Any]],
         title: str,
         job_id: str,
+        job_type: str,
         arguments: Dict[str, Any],
         created_at: int,
         started_at: Optional[int],
@@ -83,6 +87,7 @@ class Job(AttrsMixin, ReprMixin):  # pylint: disable=too-many-instance-attribute
         self._job_updater = job_updater
         self.title = title
         self.job_id = job_id
+        self._job_type = job_type
         self.arguments = arguments
         self.created_at = created_at
         self.started_at = started_at
@@ -113,6 +118,7 @@ class Job(AttrsMixin, ReprMixin):  # pylint: disable=too-many-instance-attribute
                     {
                         "title": <str>
                         "jobId": <str>
+                        "jobType"" <str>
                         "arguments": <object>
                         "createdAt": <int>
                         "startedAt": <int>
@@ -159,11 +165,9 @@ class Job(AttrsMixin, ReprMixin):  # pylint: disable=too-many-instance-attribute
 
     def abort(self) -> None:
         """Abort a :class:`Job`."""
-        self._client.open_api_do("POST", f"jobs/{self.job_id}/abort", self._dataset_id)
-
-    def retry(self) -> None:
-        """Retry a :class:`Job`."""
-        self._client.open_api_do("POST", f"jobs/{self.job_id}/retry", self._dataset_id)
+        self._client.open_api_do(
+            "POST", f"jobs/{self.job_id}/abort?jobType={self._job_type}", self._dataset_id
+        )
 
 
 class SquashAndMergeJob(Job):
@@ -176,6 +180,7 @@ class SquashAndMergeJob(Job):
         draft_getter: The function to get draft by draft_number.
         title: Title of the Job.
         job_id: ID of the Job.
+        job_type: Type of the Job.
         arguments: Arguments of the Job.
         created_at: The time when the Job is created.
         started_at: The time when the Job is started.
@@ -189,14 +194,16 @@ class SquashAndMergeJob(Job):
 
     _T = TypeVar("_T", bound="SquashAndMergeJob")
 
-    def __init__(  # pylint: disable=too-many-arguments
+    def __init__(  # pylint: disable=too-many-locals
         self,
         client: Client,
+        *,
         dataset_id: str,
         job_updater: Callable[[str], Dict[str, Any]],
         draft_getter: Callable[[int], Draft],
         title: str,
         job_id: str,
+        job_type: str,
         arguments: Dict[str, Any],
         created_at: int,
         started_at: Optional[int],
@@ -212,6 +219,7 @@ class SquashAndMergeJob(Job):
             job_updater,
             title,
             job_id,
+            job_type,
             arguments,
             created_at,
             started_at,
@@ -256,6 +264,7 @@ class SquashAndMergeJob(Job):
                     {
                         "title": <str>
                         "jobId": <str>
+                        "jobType"" <str>
                         "arguments": <object>
                         "createdAt": <int>
                         "startedAt": <int>
@@ -280,3 +289,136 @@ class SquashAndMergeJob(Job):
         job._draft_getter = draft_getter  # pylint: disable=protected-access
 
         return job
+
+    def retry(self) -> None:
+        """Retry a :class:`SquashAndMergeJob`."""
+        self._client.open_api_do(
+            "POST", f"jobs/{self.job_id}/retry?jobType={self._job_type}", self._dataset_id
+        )
+
+
+class BasicSearchJob(Job):
+    """This class defines :class:`BasicSearchJob`."""
+
+    _T = TypeVar("_T", bound="BasicSearchJob")
+
+    def __init__(  # pylint: disable=too-many-locals
+        self,
+        client: Client,
+        *,
+        dataset_id: str,
+        job_updater: Callable[[str], Dict[str, Any]],
+        is_fusion: bool,
+        title: str,
+        job_id: str,
+        job_type: str,
+        arguments: Dict[str, Any],
+        created_at: int,
+        started_at: Optional[int],
+        finished_at: Optional[int],
+        status: str,
+        error_message: str,
+        result: Optional[Dict[str, Any]],
+        description: Optional[str] = "",
+    ) -> None:
+        super().__init__(
+            client,
+            dataset_id,
+            job_updater,
+            title,
+            job_id,
+            job_type,
+            arguments,
+            created_at,
+            started_at,
+            finished_at,
+            status,
+            error_message,
+            result,
+            description,
+        )
+        self._is_fusion = is_fusion
+
+    @property
+    def result(self) -> Union[SearchResult, FusionSearchResult, None]:
+        """Get the result of the BasicSearchJob.
+
+        Returns:
+            The search result of the BasicSearchJob.
+
+        """
+        if self.status == "SUCCESS" and self._result:
+            search_result_id: str = self._result["searchResultId"]
+            search_result_commit_id: str = self._result["searchResultCommitId"]
+            if self._is_fusion:
+                return FusionSearchResult(
+                    self.job_id, search_result_id, search_result_commit_id, self._client
+                )
+            return SearchResult(
+                self.job_id, search_result_id, search_result_commit_id, self._client
+            )
+
+        return None
+
+    @classmethod
+    def from_response_body(  # type: ignore[override]  # pylint: disable=arguments-differ
+        cls: Type[_T],
+        body: Dict[str, Any],
+        *,
+        client: Client,
+        dataset_id: str,
+        job_updater: Callable[[str], Dict[str, Any]],  # noqa: DAR101
+        is_fusion: bool,
+    ) -> _T:
+        """Loads a :class:`BasicSearchJob` object from a response body.
+
+        Arguments:
+            body: The response body which contains the information of a BasicSearchJob,
+                whose format should be like::
+
+                    {
+                        "title": <str>
+                        "jobId": <str>
+                        "jobType"" <str>
+                        "arguments": <object>
+                        "createdAt": <int>
+                        "startedAt": <int>
+                        "finishedAt": <int>
+                        "status": <str>
+                        "errorMessage": <str>
+                        "result": <object>
+                        "description": <str>
+                    }
+            client: The :class:`~tensorbay.client.requests.Client`.
+            dataset_id: Dataset ID.
+            job_updater: The function to update the information of the BasicSearchJob instance.
+            if_fusion: Whether it is from fusion dataset.
+
+        Returns:
+            The loaded :class:`BasicSearchJob` object.
+
+        """
+        job = super().from_response_body(
+            body, client=client, dataset_id=dataset_id, job_updater=job_updater
+        )
+        job._is_fusion = is_fusion  # pylint: disable=protected-access
+        return job
+
+    def create_dataset(self, name: str, alias: str = "", is_public: bool = False) -> None:
+        """Create a TensorBay dataset based on the search job.
+
+        Arguments:
+            name: Name of the dataset, unique for a user.
+            alias: Alias of the dataset, default is "".
+            is_public: Whether the dataset is a public dataset.
+
+        """
+        post_data = {
+            "datasetName": name,
+            "alias": alias,
+            "isPublic": is_public,
+        }
+
+        self._client.open_api_do(
+            "POST", f"searchResults/{self.job_id}/datasets", "", json=post_data
+        )
