@@ -3,25 +3,7 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 
-"""SegmentClientBase, SegmentClient and FusionSegmentClient.
-
-The :class:`SegmentClient` is a remote concept. It
-contains the information needed for determining a unique segment in a dataset
-on TensorBay, and provides a series of methods within a segment scope,
-such as :meth:`SegmentClient.upload_label`, :meth:`SegmentClient.upload_data`,
-:meth:`SegmentClient.list_data` and so on.
-In contrast to the :class:`SegmentClient`,
-:class:`~tensorbay.dataset.segment.Segment` is a local concept.
-It represents a segment created locally. Please refer to
-:class:`~tensorbay.dataset.segment.Segment` for more information.
-
-Similarly to the :class:`SegmentClient`, the :class:`FusionSegmentClient` represents
-the fusion segment in a fusion dataset on TensorBay, and its local counterpart
-is :class:`~tensorbay.dataset.segment.FusionSegment`.
-Please refer to :class:`~tensorbay.dataset.segment.FusionSegment`
-for more information.
-
-"""
+"""The segment of remote dataset on TensorBay."""
 
 import os
 import time
@@ -36,6 +18,7 @@ from ulid import ULID, from_timestamp
 from tensorbay.client.lazy import LazyPage, PagingList
 from tensorbay.client.status import Status
 from tensorbay.dataset import AuthData, Data, Frame, RemoteData
+from tensorbay.dataset.data import DataBase
 from tensorbay.exception import FrameError, InvalidParamsError, ResourceNotExistError, ResponseError
 from tensorbay.label import Label
 from tensorbay.sensor.sensor import Sensor, Sensors
@@ -346,6 +329,42 @@ class SegmentClientBase:
 
         self._client.open_api_do("PUT", "labels", self._dataset_id, json=post_data)
 
+    def _upload_multi_label(self, data: Iterable[DataBase._Type]) -> None:
+        post_data: Dict[str, Any] = {"segmentName": self.name}
+        objects = []
+        for single_data in data:
+            label = single_data.label.dumps()
+            if not label:
+                continue
+
+            remote_path = (
+                single_data.path
+                if isinstance(single_data, RemoteData)
+                else single_data.target_remote_path
+            )
+            objects.append({"remotePath": remote_path, "label": label})
+        post_data["objects"] = objects
+        post_data.update(self._status.get_status_info())
+
+        self._client.open_api_do("PUT", "multi/data/labels", self._dataset_id, json=post_data)
+
+    def upload_label(self, data: Union[DataBase._Type, Iterable[DataBase._Type]]) -> None:
+        """Upload label with Data object to the draft.
+
+        Arguments:
+            data: The data object which represents the local file to upload.
+
+        """
+        self._status.check_authority_for_draft()
+
+        if not isinstance(data, Iterable):
+            data = [data]
+
+        for chunked_data in chunked(data, 128):
+            for single_data in chunked_data:
+                self._upload_mask_files(single_data.label)
+            self._upload_multi_label(chunked_data)
+
     @property
     def name(self) -> str:
         """Return the segment name.
@@ -408,12 +427,13 @@ class SegmentClient(SegmentClientBase):
 
         mask_urls = {}
         for key in _MASK_KEYS:
-            mask_urls[key] = LazyPage(
+            mask_urls[key] = LazyPage.from_items(
                 offset,
                 limit,
-                lambda offset, limit, k=key: self._generate_mask_urls(  # type: ignore[misc]
-                    k.upper(), offset, limit
+                lambda offset, limit, k=key.upper(): (  # type: ignore[misc]
+                    self._generate_mask_urls(k, offset, limit)
                 ),
+                (item["label"].get(key.upper(), {}).get("url") for item in response["dataDetails"]),
             )
 
         for i, item in enumerate(response["dataDetails"]):
@@ -426,9 +446,7 @@ class SegmentClient(SegmentClientBase):
             for key in _MASK_KEYS:
                 mask = getattr(label, key, None)
                 if mask:
-                    mask.url = URL.from_getter(
-                        mask_urls[key].items[i].get, mask_urls[key].pull  # type: ignore[arg-type]
-                    )
+                    mask.url = URL.from_getter(mask_urls[key].items[i].get, mask_urls[key].pull)
                     mask.cache_path = os.path.join(self._cache_path, key, mask.path)
 
             yield data
@@ -477,18 +495,6 @@ class SegmentClient(SegmentClientBase):
 
         self._synchronize_upload_info((data.get_callback_body(),))
 
-    def upload_label(self, data: Data) -> None:
-        """Upload label with Data object to the draft.
-
-        Arguments:
-            data: The data object which represents the local file to upload.
-
-        """
-        self._status.check_authority_for_draft()
-
-        self._upload_mask_files(data.label)
-        self._upload_label(data)
-
     def upload_data(self, data: Data) -> None:
         """Upload Data object to the draft.
 
@@ -729,8 +735,8 @@ class SegmentClient(SegmentClientBase):
         for key in _MASK_KEYS:
             mask = getattr(label, key, None)
             if mask:
-                mask.url = URL.from_getter(
-                    lambda k=key.upper(), r=remote_path: self._get_mask_url(k, r),
+                mask.url = URL(
+                    data_details["label"][key.upper()]["url"],
                     lambda k=key.upper(), r=remote_path: (  # type: ignore[misc, arg-type]
                         self._get_mask_url(k, r)
                     ),
@@ -927,7 +933,7 @@ class FusionSegmentClient(SegmentClientBase):
         callback_bodies = []
         for sensor_name, data in frame.items():
             try:
-                callback_body = data.get_callback_body()  # type:ignore[union-attr]
+                callback_body = data.get_callback_body()
             except AttributeError:
                 continue
 
