@@ -5,15 +5,26 @@
 
 """Related methods of the TensorBay version control."""
 
-from typing import Any, Callable, Dict, Generator, Optional, Union
+from typing import Any, Callable, Dict, Generator, List, Optional, Tuple, Union
 
-from tensorbay.client.job import SquashAndMergeJob
+from tensorbay.client.job import BasicSearchJob, SquashAndMergeJob
 from tensorbay.client.lazy import PagingList
 from tensorbay.client.requests import Client
 from tensorbay.client.status import Status
 from tensorbay.client.struct import Branch, Commit, Draft, Tag
 from tensorbay.exception import ResourceNotExistError, StatusError
 
+_KEY_TO_TITLES = {
+    "segment": "Segment",
+    "withLabel": "With/Without Label",
+    "frame": "Frame",
+    "sensor": "Sensor",
+    "size": "Size",
+    "category": "Category",
+    "attribute": "Attribute",
+    "keyword": "Data Name",
+}
+
 
 class VersionControlMixin:  # pylint: disable=too-many-public-methods
     """A mixin class supporting version control methods."""
@@ -523,11 +534,11 @@ class JobMixin:
     _dataset_id: str
     _client: Client
     _status: Status
+    _JOB_TYPE: str
 
     def _create_job(
         self,
         title: str,
-        job_type: str,
         arguments: Dict[str, Any],
         description: str = "",
     ) -> Dict[str, Any]:
@@ -535,7 +546,6 @@ class JobMixin:
 
         Arguments:
             title: The Job title.
-            job_type: The type of Job.
             arguments: The arguments dict of the specific job.
             description: The Job description.
 
@@ -543,7 +553,11 @@ class JobMixin:
             The info of the job.
 
         """
-        post_data: Dict[str, Any] = {"title": title, "jobType": job_type, "arguments": arguments}
+        post_data: Dict[str, Any] = {
+            "title": title,
+            "jobType": self._JOB_TYPE,
+            "arguments": arguments,
+        }
         if description:
             post_data["description"] = description
 
@@ -553,6 +567,7 @@ class JobMixin:
 
         response.update(
             title=title,
+            jobType=self._JOB_TYPE,
             arguments=arguments,
             status="QUEUING",
             description=description,
@@ -569,13 +584,17 @@ class JobMixin:
             The info of Job.
 
         """
-        return self._client.open_api_do(  # type: ignore[no-any-return]
-            "GET", f"jobs/{job_id}", self._dataset_id
+        params = {"jobType": self._JOB_TYPE}
+
+        response: Dict[str, Any] = self._client.open_api_do(
+            "GET", f"jobs/{job_id}", self._dataset_id, params=params
         ).json()
 
+        response.update(jobType=self._JOB_TYPE)
+        return response
+
     def _list_jobs(
         self,
-        job_type: str,
         status: Optional[str] = None,
         offset: int = 0,
         limit: int = 128,
@@ -583,7 +602,6 @@ class JobMixin:
         """Get a dict containing the information of :class:`Job` list.
 
         Arguments:
-            job_type: Type of the Job.
             status: The Job status which includes "QUEUING", "PROCESSING", "SUCCESS", "FAILED",
                     "ABORTED" and None. None means all kinds of status.
             offset: The offset of the page.
@@ -593,10 +611,14 @@ class JobMixin:
             A dict containing the information of Job list.
 
         """
-        params = {"jobType": job_type, "status": status, "offset": offset, "limit": limit}
+        params = {"jobType": self._JOB_TYPE, "status": status, "offset": offset, "limit": limit}
 
-        response = self._client.open_api_do("GET", "jobs", self._dataset_id, params=params)
-        return response.json()  # type: ignore[no-any-return]
+        response: Dict[str, Any] = self._client.open_api_do(
+            "GET", "jobs", self._dataset_id, params=params
+        ).json()
+
+        response.update(jobType=self._JOB_TYPE)
+        return response
 
     def delete_job(self, job_id: str) -> None:
         """Delete a :class:`Job`.
@@ -605,7 +627,9 @@ class JobMixin:
             job_id: The Job id.
 
         """
-        self._client.open_api_do("DELETE", f"jobs/{job_id}", self._dataset_id)
+        self._client.open_api_do(
+            "DELETE", f"jobs/{job_id}?jobType={self._JOB_TYPE}", self._dataset_id
+        )
 
 
 class SquashAndMerge(JobMixin):
@@ -639,7 +663,7 @@ class SquashAndMerge(JobMixin):
         offset: int = 0,
         limit: int = 128,
     ) -> Generator[SquashAndMergeJob, None, int]:
-        response = self._list_jobs(self._JOB_TYPE, status, offset, limit)
+        response = self._list_jobs(status, offset, limit)
         for item in response["jobs"]:
             yield SquashAndMergeJob.from_response_body(
                 item,
@@ -709,7 +733,7 @@ class SquashAndMerge(JobMixin):
         if draft_description:
             arguments["description"] = draft_description
 
-        job_info = self._create_job(title, self._JOB_TYPE, arguments, description)
+        job_info = self._create_job(title, arguments, description)
         return SquashAndMergeJob.from_response_body(
             job_info,
             dataset_id=self._dataset_id,
@@ -752,3 +776,137 @@ class SquashAndMerge(JobMixin):
             lambda offset, limit: self._generate_jobs(status, offset, limit),
             128,
         )
+
+
+class BasicSearch(JobMixin):
+    """This class defines :class:`BasicSearch`.
+
+    Arguments:
+        client: The :class:`~tensorbay.client.requests.Client`.
+        dataset_id: Dataset ID.
+        status: The version control status of the dataset.
+        is_fusion: Whether the dataset searched is a fusion dataset.
+
+    """
+
+    _JOB_TYPE = "basicSearch"
+
+    def __init__(self, client: Client, dataset_id: str, status: Status, is_fusion: bool) -> None:
+        self._client = client
+        self._dataset_id = dataset_id
+        self._status = status
+        self._is_fusion = is_fusion
+
+    def _generate_jobs(
+        self,
+        status: Optional[str] = None,
+        offset: int = 0,
+        limit: int = 128,
+    ) -> Generator[BasicSearchJob, None, int]:
+        response = self._list_jobs(status, offset, limit)
+        for item in response["jobs"]:
+            yield BasicSearchJob.from_response_body(
+                item,
+                dataset_id=self._dataset_id,
+                client=self._client,
+                job_updater=self._get_job,
+                is_fusion=self._is_fusion,
+            )
+
+        return response["totalCount"]  # type: ignore[no-any-return]
+
+    def create_job(
+        self,
+        title: str = "",
+        description: str = "",
+        *,
+        conjunction: str,
+        filters: List[Tuple[Any, ...]],
+        unit: str = "file",
+    ) -> BasicSearchJob:
+        """Create a :class:`BasicSearchJob`.
+
+        Arguments:
+            title: The BasicSearchJob title.
+            description: The BasicSearchJob description.
+            conjunction: The logical conjunction between search filters, which includes "and" and
+                "or".
+            filters: The list of basic search criteria.
+            unit: The unit of basic search. There are two options:
+
+                1. "file": get the data that meets search filters;
+                2. "frame": if at least one data in a frame meets search filters, all data in
+                    the frame will be get. This option only works on fusion dataset.
+
+        Returns:
+            The BasicSearchJob.
+
+        """
+        self._status.check_authority_for_commit()
+
+        if not title:
+            title = (
+                f"search({self._status.commit_id[:7]}): "  # type: ignore[index]
+                f"{' '.join(filters[0][:2])} ..."
+            )
+
+        new_filters = [
+            dict(zip(("key", "operator", "value", "labelType"), filter_)) for filter_ in filters
+        ]
+
+        for new_filter in new_filters:
+            new_filter["title"] = _KEY_TO_TITLES[new_filter["key"]]
+            label_type = new_filter.pop("labelType", None)
+            if label_type:
+                new_filter["extraInfo"] = {"labelType": label_type}
+
+        arguments = {
+            "commit": self._status.commit_id,
+            "conjunction": conjunction,
+            "filters": new_filters,
+            "unit": unit,
+        }
+
+        job_info = self._create_job(title, arguments, description)
+        return BasicSearchJob.from_response_body(
+            job_info,
+            dataset_id=self._dataset_id,
+            client=self._client,
+            job_updater=self._get_job,
+            is_fusion=self._is_fusion,
+        )
+
+    def get_job(self, job_id: str) -> BasicSearchJob:
+        """Get a :class:`BasicSearchJob`.
+
+        Arguments:
+            job_id: The BasicSearchJob id.
+
+        Returns:
+            The BasicSearchJob.
+
+        """
+        job_info = self._get_job(job_id)
+        return BasicSearchJob.from_response_body(
+            job_info,
+            dataset_id=self._dataset_id,
+            client=self._client,
+            job_updater=self._get_job,
+            is_fusion=self._is_fusion,
+        )
+
+    def list_jobs(self, status: Optional[str] = None) -> PagingList[BasicSearchJob]:
+        """List the BasicSearchJob.
+
+        Arguments:
+            status: The BasicSearchJob status which includes "QUEUING", "PROCESSING", "SUCCESS",
+                    "FAIL", "ABORT" and None. None means all kinds of status.
+
+        Returns:
+            The PagingList of BasicSearchJob.
+
+        """
+        return PagingList(
+            lambda offset, limit: self._generate_jobs(status, offset, limit),
+            128,
+        )
