@@ -3,7 +3,7 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 
-"""mixin classes for local file and remote file."""
+"""Basic concepts of local file and remote file."""
 
 import os
 from hashlib import sha1
@@ -161,21 +161,33 @@ class RemoteFileMixin(ReprMixin):
 
     def _urlopen(self) -> UserResponse:
 
-        url = self.get_url()
         if not self.url:
             raise ValueError(f"The file cannot open because {self._repr_head()} has no url")
 
         try:
             session = get_session()
-            return UserResponse(session.request("GET", url, timeout=config.timeout, stream=True))
+            return UserResponse(
+                session.request("GET", self.get_url(), timeout=config.timeout, stream=True)
+            )
         except ResponseError as error:
             if error.response.status_code == 403:
                 self.url.update()
                 return UserResponse(
-                    get_session().request("GET", url, timeout=config.timeout, stream=True)
+                    get_session().request(
+                        "GET", self.get_url(), timeout=config.timeout, stream=True
+                    )
                 )
             raise
 
+    def _write_cache(self, cache_path: str) -> None:
+        dirname = os.path.dirname(cache_path)
+        os.makedirs(dirname, exist_ok=True)
+        temp_path = f"{cache_path}.tensorbay.downloading.{os.getpid()}"
+        with self._urlopen() as fp:
+            with open(temp_path, "wb") as cache:
+                cache.write(fp.read())
+        os.rename(temp_path, cache_path)
+
     def get_url(self) -> str:
         """Return the url of the data hosted by tensorbay.
 
@@ -205,11 +217,15 @@ class RemoteFileMixin(ReprMixin):
             return self._urlopen()
 
         if not os.path.exists(cache_path):
-            dirname = os.path.dirname(cache_path)
-            os.makedirs(dirname, exist_ok=True)
-
-            with self._urlopen() as fp:
-                with open(cache_path, "wb") as cache:
-                    cache.write(fp.read())
+            self._write_cache(cache_path)
 
         return open(cache_path, "rb")
+
+    def get_callback_body(self) -> Dict[str, Any]:
+        """Not support ``get_callback_body`` function.
+
+        Raises:
+            AttributeError: when calling the ``get_callback_body()``.
+
+        """
+        raise AttributeError(f"Could not dump a '{self.__class__.__name__}' instance")
